@@ -1,6 +1,15 @@
 # ------------------------------------------------------------------------------------------
 #                             Shapley Lorenz Function
 # ------------------------------------------------------------------------------------------
+import numpy as np
+import pandas as pd
+import matplotlib.pyplot as plt
+from sklearn.utils import shuffle
+from scipy.special import binom, factorial
+import itertools
+from tqdm import tqdm
+import warnings
+
 
 class ShapleyLorenzShare:
     '''
@@ -8,7 +17,7 @@ class ShapleyLorenzShare:
 
     Parameters:
     ---------------------------------------------------------
-    model : method
+    model : method^
         specifies the prediction model
     X_dist : numpy.array
         n x p matrix containing the model covariates. Typically the training observations. This is used as a proxy for the empirical distribution of the covariates.
@@ -28,9 +37,10 @@ class ShapleyLorenzShare:
             warnings.warn('A background dataset larger than 50, may cause prohibitive long runtime. Consider using a sample of maximally 100 observations.')
             user_input = str(input("Enter 's' to sample 50 observations and enter 'c', to continue with current background dataset"))
             if user_input == 's':
-                idx = np.random.randint(self.N,50)
+                idx = np.random.randint(0,self.N,50)
                 self.data.data = self.data.data[idx,:]
                 self.data = standardise_data_format(self.data.data)
+                self.N = self.data.data.shape[0]
                 if len(self.y_bg.shape) == 1:
                     try:
                         self.y_bg = self.y_bg.iloc[idx]
